==> ember-0.4.0.tar.bz2: ember-0.4.0/src/components/ogre/model/ParticleSystem.cpp <==
//
// C++ Implementation: ParticleSystem
//
// Description: 
//
//
// Author: Erik Hjortsberg <erik@katastrof.nu>, (C) 2005
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.//
//
#include "ParticleSystem.h"
#include "ParticleSystemBinding.h"

namespace EmberOgre {
namespace Model {

Ogre::ParticleSystem* ParticleSystem::getOgreParticleSystem()
{
	return mOgreParticleSystem;
}

ParticleSystem::ParticleSystem(Ogre::ParticleSystem* ogreParticleSystem) : 
		mOgreParticleSystem(ogreParticleSystem)
{
	assert(ogreParticleSystem);
}

ParticleSystem::~ParticleSystem()
{
	//make sure all bindings are removed
	ParticleSystemBindingsPtrSet::const_iterator I = mBindings.begin();
	ParticleSystemBindingsPtrSet::const_iterator I_end = mBindings.end();
	for (; I != I_end; ++I) {
		ParticleSystemBinding* binding = *I;
		delete binding;
	}
	mBindings.clear();
	
	//and then destroy the system to save resources
	Ogre::ParticleSystemManager::getSingleton().destroySystem(mOgreParticleSystem);
	
}


ParticleSystemBindingsPtrSet& ParticleSystem::getBindings( )
{
	return mBindings;
}

ParticleSystemBinding * ParticleSystem::addBinding( const std::string & emitterVal, const std::string & variableName )
{
	ParticleSystemBinding* binding = new ParticleSystemBinding(this, emitterVal, variableName);
	mBindings.push_back(binding);
	return binding;
}

}
}

==> ember-0.5.0.tar.bz2: ember-0.5.0/src/components/ogre/model/ParticleSystem.cpp <==
//
// C++ Implementation: ParticleSystem
//
// Description: 
//
//
// Author: Erik Hjortsberg <erik@katastrof.nu>, (C) 2005
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.//
//
#include "ParticleSystem.h"
#include "ParticleSystemBinding.h"

namespace EmberOgre {
namespace Model {

Ogre::ParticleSystem* ParticleSystem::getOgreParticleSystem()
{
	return mOgreParticleSystem;
}

ParticleSystem::ParticleSystem(Ogre::ParticleSystem* ogreParticleSystem) : 
		mOgreParticleSystem(ogreParticleSystem)
{
	assert(ogreParticleSystem);
}

ParticleSystem::~ParticleSystem()
{
	//make sure all bindings are removed
	ParticleSystemBindingsPtrSet::const_iterator I = mBindings.begin();
	ParticleSystemBindingsPtrSet::const_iterator I_end = mBindings.end();
	for (; I != I_end; ++I) {
		delete *I;
	}
	mBindings.clear();
	
	//and then destroy the system to save resources
	mOgreParticleSystem->_getManager()->destroyParticleSystem(mOgreParticleSystem);
	
}


ParticleSystemBindingsPtrSet& ParticleSystem::getBindings( )
{
	return mBindings;
}

ParticleSystemBinding * ParticleSystem::addBinding( const std::string & emitterVal, const std::string & variableName )
{
	ParticleSystemBinding* binding = new ParticleSystemBinding(this, emitterVal, variableName);
	mBindings.push_back(binding);
	return binding;
}

}
}
